@@ -271,7 +271,7 @@ def parse_components(msg):
                         cc['sf'] = c.params['sf']
                         cc['val'] = next((f['val'] for f in fields if f['sf'] == c.params['sf']), None)
                     elif 'key' in c.params:
-                        cc['key'] = i.params['key']
+                        cc['key'] = c.params['key']
                         cc['val'] = next((f['val'] for f in fields if f['key'] == c.params['key']), None)
                     else:
                         cc['val'] = next((f['val'] for f in fields if ('key' not in f and 'sf' not in f)), None)
